<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is a proprietary licensed product.
 * For more information see License.txt in the plugin folder.

 * ---
 * Copyright (c) 2018, Ebenezer Obasi
 * All rights reserved.
 * info@eobasi.com.

 * Redistribution and use in source and binary forms, with or without modification, are not permitted provided.

 * This plugin should be bought from the developer. For details contact info@eobasi.com.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

 /**
 * MASTERLOGIN_CLASS_EventHandler
 *
 * @author Ebenezer Obasi <info@eobasi.com>
 * @package ow_plugins.masterlogin.classes
 * @since 1.8.4
 */

class MASTERLOGIN_CLASS_EventHandler
{
    /**
     * @var BOL_UserService
     */
    private $userService;

    /**
     * @var MASTERLOGIN_CLASS_SERVICE
     */
    private $service;

    /**
     * Singleton instance.
     *
     * @var MASTERLOGIN_CLASS_EventHandler
     */
    private static $classInstance;

    /**
     * Returns an instance of class (singleton pattern implementation).
     *
     * @return MASTERLOGIN_CLASS_EventHandler
     */
    public static function getInstance()
    {
        if ( self::$classInstance === null )
        {
            self::$classInstance = new self();
        }

        return self::$classInstance;
    }

    private function __construct()
    {
        $this->userService = BOL_UserService::getInstance();
        $this->service = MASTERLOGIN_BOL_Service::getInstance();
    }

    public function init()
    {
		OW::getEventManager()->bind(BASE_CMP_ProfileActionToolbar::EVENT_NAME, array($this, 'userAuthTool'));
        OW::getEventManager()->bind('base.add_main_console_item', array($this, 'onCollectConsoleItems'));
		 OW::getEventManager()->bind(OW_EventManager::ON_USER_LOGOUT, array($this, 'onUserLogout'));
    }

	public function onUserLogout( OW_Event $e )
	{
		if( !$this->service->isAdminSet( ) )
        {
            return;
        }

		$this->service->deleteAdmin( );
	}

    public function onCollectConsoleItems( BASE_CLASS_EventCollector $event )
    {
        if( !OW::getUser()->isAuthenticated() || !$this->service->isAdminSet( ) )
        {
            return;
        }

        $displayName = $this->userService->getDisplayName( $this->service->getAdmin( ) );

		$event->add(array(
			'label' => OW::getLanguage()->text('masterlogin', 'console_menu_label', array('displayName' => $displayName)),
			'url' => OW_Router::getInstance()->urlForRoute('masterlogin_auth_return')
		));

    }

    public function userAuthTool( BASE_CLASS_EventCollector $event )
    {
        if ( !OW::getUser()->isAuthenticated() || !OW::getUser()->isAdmin() )
        {
            return;
        }

        $params = $event->getParams();

        if ( empty($params['userId']) || $params['userId'] == OW::getUser()->getId() )
        {
            return;
        }

        $userId = $params['userId'];

        $displayName = $this->userService->getDisplayName( $userId );

        $resultArray = array(
            BASE_CMP_ProfileActionToolbar::DATA_KEY_LABEL => OW::getLanguage()->text('masterlogin', 'login_label', array('displayName' => $displayName)),
            BASE_CMP_ProfileActionToolbar::DATA_KEY_LINK_HREF => OW::getRouter()->urlForRoute('masterlogin_auth_login', array('uid' => $userId)),
            BASE_CMP_ProfileActionToolbar::DATA_KEY_LINK_ID => uniqid('masterlogin-login_as_user-'),
            BASE_CMP_ProfileActionToolbar::DATA_KEY_ITEM_KEY => "masterlogin-login_as_user",
            BASE_CMP_ProfileActionToolbar::DATA_KEY_LINK_ORDER => 4
        );

        $event->add($resultArray);
    }



}